UnitIdentifier

Enum UnitIdentifier 

pub enum UnitIdentifier {
Show 44 variants Derived(Box<UnitIdentifier>, Box<UnitIdentifier>), Acre, Bit, Byte, Celsius, Centimeter, Day, Degree, Fahrenheit, Foot, Gallon, Gigabit, Gigabyte, Gram, Hectare, Hour, Inch, Kilobit, Kilobyte, Kilogram, Kilometer, Liter, Megabit, Megabyte, Meter, Microsecond, Mile, Milliliter, Millimeter, Millisecond, Minute, Month, Nanosecond, Ounce, Percent, Petabyte, Pound, Second, Stone, Terabit, Terabyte, Week, Yard, Year,
}

Variants



Derived(Box<UnitIdentifier>, Box<UnitIdentifier>)



Acre



Bit



Byte



Celsius



Centimeter



Day



Degree



Fahrenheit



Foot



Gallon



Gigabit



Gigabyte



Gram



Hectare



Hour



Inch



Kilobit



Kilobyte



Kilogram



Kilometer



Liter



Megabit



Megabyte



Meter



Microsecond



Mile



Milliliter



Millimeter



Millisecond



Minute



Month



Nanosecond



Ounce



Percent



Petabyte



Pound



Second



Stone



Terabit



Terabyte



Week



Yard



Year

Implementations